@@ -66,7 +66,7 @@ class A79ClientExternal:
 
         # Since sub-workflows are also treated as a single tool call, we need to wait for
         # a longer time. Setting it to 15 minutes for now to handle sub-workflows.
-        wait_time_secs = 5
+        wait_time_secs = 0.25
         total_wait_time_secs = 15 * 60  # 15 minutes
         number_of_attempts = total_wait_time_secs / wait_time_secs
         while number_of_attempts > 0:
@@ -75,6 +75,7 @@ class A79ClientExternal:
                 f"{self.base_url}/api/v1/tool/status/{task_id}", headers=self.headers
             )
             response.raise_for_status()
+            wait_time_secs = min(wait_time_secs * 2, 5)
             if response.json()["status"] == "running":
                 time.sleep(wait_time_secs)
                 continue
