@@ -2,29 +2,14 @@ from enum import Enum
 
 from pydantic import BaseModel, Field
 
-from .. import enums
 from . import ToolOutput
 
 
 class FieldFormat(str, Enum):
-    COMMA_SEPARATED_LIST = "comma-separated-list"
     JINJA_TEMPLATE = "jinja-template"
     DEFAULT = "default"
 
 
-# TODO: this tool probably needs to be replaced by something that reads only a single
-# datasource at a time, or takes in a list of datasource IDs.
-class ReadDatasourcesInput(BaseModel):
-    datasource_ids: str = Field(
-        default="",
-        json_schema_extra={
-            "mandatory": True,
-            "field_type": enums.CustomDataType.DOCUMENT.value,
-            "format": FieldFormat.COMMA_SEPARATED_LIST.value,
-        },
-    )
-
-
 class ReadDatasourcesOutput(ToolOutput):
     content: str = Field(default="")  # type: ignore
 
