@@ -3,11 +3,9 @@ from enum import Enum
 from typing import Optional
 from urllib.parse import quote_plus, urlparse
 
-from pydantic import BaseModel, ConfigDict, Field, field_validator
+from pydantic import BaseModel, ConfigDict, Field, field_validator, model_validator
 from sqlalchemy.engine import URL
 
-from . import ToolOutput
-
 
 class SqlType(str, Enum):
     INTEGER = "integer"
@@ -30,6 +28,7 @@ class SqlDialect(str, Enum):
     MSSQL = "mssql"
     ORACLE = "oracle"
     SNOWFLAKE = "snowflake"
+    DUCKDB = "duckdb"
 
 
 class DatabaseCredentials(BaseModel):
@@ -310,7 +309,7 @@ class SourceSelectionInput(BaseModel):
             try:
                 config = SQADatabaseConfig(**v)
             except Exception as e:
-                raise ValueError(f"Invalid database configuration: {str(e)}")
+                raise ValueError("Invalid database configuration") from e
         else:
             raise ValueError(
                 "database_config must be a dictionary or SQADatabaseConfig object"
@@ -347,7 +346,7 @@ class SourceSelectionInput(BaseModel):
         return config
 
 
-class SourceSelectionOutput(ToolOutput):
+class SourceSelectionOutput(BaseModel):
     """Output model for source/table selection"""
 
     relevant_tables: list[dict[str, t.Any]] = Field(
@@ -361,7 +360,41 @@ class SourceSelectionOutput(ToolOutput):
     )
 
 
-class NLToSQLInput(BaseModel):
+class DatabaseSourceInput(BaseModel):
+    """Base model for inputs that can use either a connector or CSV files"""
+
+    connector_name: t.Optional[str] = Field(
+        default=None, description="Name of the connector to use for the database"
+    )
+    files: t.Optional[list[str]] = Field(
+        default=None,
+        description="List of CSV files to query (will use their PostgreSQL tables)",
+    )
+
+    @model_validator(mode="after")
+    def validate_connector_or_files(self):
+        """Ensure either connector_name or files is provided, but not both"""
+        if self.connector_name and self.files:
+            raise ValueError(
+                "Cannot specify both 'connector_name' and 'files'. "
+                "Please use one or the other."
+            )
+        if not self.connector_name and not self.files:
+            raise ValueError("Either 'connector_name' or 'files' must be provided.")
+
+        # Validate that all files are CSV files
+        if self.files:
+            for file in self.files:
+                if not file.lower().endswith(".csv"):
+                    raise ValueError(
+                        f"Only CSV files are supported. "
+                        f"File '{file}' is not a CSV file."
+                    )
+
+        return self
+
+
+class NLToSQLInput(DatabaseSourceInput):
     """Input model for NL-to-SQL conversion"""
 
     query: str = Field(description="Natural language query to convert to SQL")
@@ -374,12 +407,9 @@ class NLToSQLInput(BaseModel):
         default=None,
         description="Optional sample data to provide context for SQL generation",
     )
-    connector_name: str = Field(
-        description="Name of the connector to use for the database"
-    )
 
 
-class NLToSQLOutput(ToolOutput):
+class NLToSQLOutput(BaseModel):
     """Output model for NL-to-SQL conversion"""
 
     sql_query: str = Field(description="Generated PostgreSQL query")
@@ -396,76 +426,85 @@ class NLToSQLOutput(ToolOutput):
     database_name: str = Field(description="Name of the database used")
 
 
-class ExecuteSQLInput(BaseModel):
-    """Input model for SQL execution"""
+class ExecuteSQLInput(DatabaseSourceInput):
+    """Input model for SQL execution with automatic result capping and pagination"""
 
     sql_query: str = Field(description="SQL query to execute")
-    database_name: str = Field(description="Name of the database to execute the query on")
-    connector_name: str = Field(
-        description="Name of the connector to use for the database"
+    database_name: Optional[str] = Field(
+        default=None, description="Name of the database to execute the query on"
     )
-    limit: Optional[int] = Field(
-        default=None, description="Optional limit for the number of rows to return"
+    page: int = Field(
+        default=1,
+        ge=1,
+        description=(
+            "Page number for pagination (1-based). Each page contains up to "
+            "max_rows_per_page results."
+        ),
+    )
+    max_rows_per_page: int = Field(
+        default=100,
+        ge=1,
+        le=1000,
+        description=(
+            "Maximum number of rows to return per page (capped at 1000 for safety)"
+        ),
     )
 
 
-class ExecuteSQLOutput(ToolOutput):
-    """Output model for SQL execution returning a pandas DataFrame"""
+class ExecuteSQLOutput(BaseModel):
+    """Output model for SQL execution with pagination metadata"""
 
     data: list[dict[str, t.Any]] = Field(
         description="Query results as a list of dictionaries (rows)"
     )
+    sql_query: str = Field(description="SQL query that was executed")
     columns: list[str] = Field(description="Column names in the result set")
-    row_count: int = Field(description="Total number of rows returned")
-    database_name: str = Field(
-        description="Name of the database where query was executed"
+    total_rows: int = Field(
+        description="Total number of rows available in the complete result set"
     )
-    execution_time_ms: Optional[float] = Field(
-        default=None, description="Query execution time in milliseconds"
+    page: int = Field(description="Current page number (1-based)")
+    max_rows_per_page: int = Field(description="Maximum rows per page that was requested")
+    rows_in_page: int = Field(description="Actual number of rows returned in this page")
+    total_pages: int = Field(description="Total number of pages available")
+    has_next_page: bool = Field(description="Whether there are more pages available")
+    has_previous_page: bool = Field(
+        description="Whether there are previous pages available"
     )
 
 
-class ListDatabasesInput(BaseModel):
+class ListDatabasesInput(DatabaseSourceInput):
     """Input model for listing databases"""
 
-    connector_name: str = Field(
-        description="Name of the connector to use for the database"
-    )
+    pass  # Inherits connector_name/files fields from DatabaseSourceInput
 
 
-class ListDatabasesOutput(ToolOutput):
+class ListDatabasesOutput(BaseModel):
     """Output model for listing databases"""
 
     databases: list[str] = Field(description="List of available database names")
 
 
-class ListSchemasInput(BaseModel):
+class ListSchemasInput(DatabaseSourceInput):
     """Input model for listing schemas in a database"""
 
     database_name: str = Field(description="Name of the database to list schemas from")
-    connector_name: str = Field(
-        description="Name of the connector to use for the database"
-    )
 
 
-class ListSchemasOutput(ToolOutput):
+class ListSchemasOutput(BaseModel):
     """Output model for listing schemas"""
 
     schemas: list[str] = Field(description="List of schema names in the database")
     database_name: str = Field(description="Name of the database")
 
 
-class ListTablesInput(BaseModel):
+class ListTablesInput(DatabaseSourceInput):
     """Input model for listing tables in a schema"""
 
     database_name: str = Field(description="Name of the database")
     schema_name: str = Field(description="Name of the schema to list tables from")
-    connector_name: str = Field(
-        description="Name of the connector to use for the database"
-    )
 
 
-class ListTablesOutput(ToolOutput):
+class ListTablesOutput(BaseModel):
     """Output model for listing tables"""
 
     tables: list[str] = Field(description="List of table names in the schema")
@@ -474,19 +513,16 @@ class ListTablesOutput(ToolOutput):
     count: int = Field(description="Total number of tables")
 
 
-class SearchTablesInput(BaseModel):
+class SearchTablesInput(DatabaseSourceInput):
     """Input model for searching tables using natural language"""
 
     query: str = Field(description="Natural language query to search for relevant tables")
-    connector_name: str = Field(
-        description="Name of the connector to use for the database"
-    )
     num_tables: int = Field(
         default=10, ge=1, description="Maximum number of relevant tables to return"
     )
 
 
-class SearchTablesOutput(ToolOutput):
+class SearchTablesOutput(BaseModel):
     """Output model for table search results"""
 
     relevant_tables: list[dict[str, t.Any]] = Field(
@@ -494,3 +530,60 @@ class SearchTablesOutput(ToolOutput):
     )
     explanation: str = Field(description="Explanation of why these tables were selected")
     count: int = Field(description="Number of tables found")
+
+
+class PeekTableInput(DatabaseSourceInput):
+    """Input model for peeking at table data"""
+
+    table_name: str = Field(description="Name of the table to peek at")
+    database_name: Optional[str] = Field(
+        default=None, description="Name of the database (required for connectors)"
+    )
+    schema_name: Optional[str] = Field(
+        default=None,
+        description="Name of the schema (optional, defaults to default schema)",
+    )
+    num_rows: int = Field(
+        default=10, ge=1, le=100, description="Number of rows to return (1-100)"
+    )
+
+
+class ListColumnsInput(DatabaseSourceInput):
+    """Input model for listing columns in a table"""
+
+    table_name: str = Field(description="Name of the table to list columns from")
+    database_name: Optional[str] = Field(
+        default=None, description="Name of the database (required for connectors)"
+    )
+    schema_name: Optional[str] = Field(
+        default=None,
+        description="Name of the schema (optional, defaults to default schema)",
+    )
+
+
+class ListColumnsOutput(BaseModel):
+    """Output model for listing columns with table definition"""
+
+    columns: list[dict[str, t.Any]] = Field(
+        description="List of column definitions with name, type, constraints, etc."
+    )
+    table_name: str = Field(description="Name of the table")
+    database_name: str = Field(description="Name of the database")
+    schema_name: str = Field(description="Name of the schema")
+
+
+class GetTableNameForCsvInput(BaseModel):
+    """Input model for getting table name mapping for CSV files"""
+
+    file: str = Field(description="Name of the file to get table mapping for")
+
+
+class GetTableNameForCsvOutput(BaseModel):
+    """Output model for CSV table name mapping"""
+
+    database_name: str = Field(description="Database name where the CSV table is stored")
+    schema_name: str = Field(description="Schema name where the CSV table is stored")
+    table_name: str = Field(description="Actual table name in the database")
+    full_table_name: str = Field(
+        description="Full qualified table name (database.schema.table)"
+    )
