@@ -1,6 +1,5 @@
 from pydantic import BaseModel, Field
 
-from ..enums import ContentType
 from . import ToolOutput
 
 
@@ -12,8 +11,8 @@ class ParseDocumentInput(BaseModel):
             "URL of the document to download and parse, or the document content itself"
         ),
     )
-    content_type: ContentType = Field(
-        default=ContentType.PLAIN_TEXT,
+    content_type: str = Field(
+        default="text/plain",
         description=(
             "Content type of the document "
             "(auto-detected for URLs, optional for direct content)"
