@@ -4,7 +4,6 @@ from enum import Enum
 from pydantic import BaseModel, ConfigDict, Field, field_serializer, field_validator
 from pydantic.json_schema import SkipJsonSchema
 
-from ...utils.pydantic_utils import deserialize_model, serialize_model
 from ...utils.workflow_utils import ErrorHandling
 from .. import enums
 from . import ToolOutput
@@ -57,7 +56,7 @@ class ChatInput(BaseModel):
         if value is None:
             return None  # type: ignore
         elif isinstance(value, type) and issubclass(value, BaseModel):
-            return serialize_model(value)
+            return value.model_json_schema()
         else:
             return value  # type: ignore
 
@@ -76,21 +75,6 @@ class ChatInput(BaseModel):
             value = f"{cls.MODEL_PREFIX}{value}"
         return value  # type: ignore
 
-    @field_validator("output_schema")
-    @classmethod
-    def parse_inference_schema(
-        cls, value: dict[str, t.Any] | type[BaseModel] | None
-    ) -> dict[str, t.Any] | type[BaseModel] | None:
-        if value is None:
-            return None
-        elif isinstance(value, dict):
-            try:
-                return deserialize_model(value)
-            except Exception:
-                return value
-        else:
-            return value
-
 
 class ChatOutput(ToolOutput):
     llm_call: SkipJsonSchema[dict[str, t.Any]] = Field(default_factory=dict)
