@@ -15,7 +15,7 @@ class ChatMessage(BaseModel):
 class ChatOptions(BaseModel):
     """Options for configuring Perplexity chat behavior."""
 
-    model: str = "llama-3.1-sonar-small-128k-online"
+    model: str = "sonar"
     system_message: str | None = None
     max_tokens: int | None = None
     temperature: float | None = None
