@@ -2,8 +2,7 @@ import typing as t
 
 from pydantic import BaseModel, Field
 
-from common_py.model import enums
-
+from .. import enums
 from . import ToolOutput
 
 
