@@ -20,7 +20,7 @@ class ReactAgentInput(BaseModel):
         description="Available tools for the agent to use and their definitions",
     )
     model_name: str = Field(
-        default=enums.ModelName.O4_MINI,
+        default=enums.ModelName.GPT_4O,
         description="The LLM model to use for the React agent",
     )
     system_message: str = Field(
