@@ -19,6 +19,10 @@ class RunWorkflowInput(BaseModel):
     workflow_inputs: dict[str, t.Any] = Field(
         description="Optional input data to pass to the workflow"
     )
+    output_vars: list[str] | None = Field(
+        default=None,
+        description="Optional list of output variables to return from the workflow",
+    )
     parent_run_id: str | None = None
     parent_node_id: str | None = None
 
