@@ -6,6 +6,7 @@ from . import (
     call_task_output_parser,
     clinical_trials_search,
     datasource,
+    db,
     document,
     edgartool,
     email,
@@ -15,6 +16,7 @@ from . import (
     folder,
     gmail,
     google,
+    googlecalendar,
     llm,
     nl_to_sql,
     operators,
@@ -33,14 +35,17 @@ from . import (
     thoughtspot,
     workflow,
     worksheet,
+    zoom,
 )
 
 __all__ = [
     "audio",
     "call_task_generator",
     "call_task_output_parser",
+    "chart",
     "clinical_trials_search",
     "datasource",
+    "db",
     "document",
     "edgartool",
     "email",
@@ -50,6 +55,7 @@ __all__ = [
     "folder",
     "google",
     "gmail",
+    "googlecalendar",
     "llm",
     "nl_to_sql",
     "operators",
@@ -68,4 +74,5 @@ __all__ = [
     "thoughtspot",
     "workflow",
     "worksheet",
+    "zoom",
 ]
