@@ -46,9 +46,9 @@ class ToggleInfo(BaseModel):
             try:
                 # Try to convert string to enum
                 return ToggleSection(value)
-            except ValueError:
+            except ValueError as e:
                 # If the string doesn't match any enum value
-                raise ValueError(f"Invalid section value: {value}")
+                raise ValueError(f"Invalid section value: {value}") from e
         return value
 
 
